/*
   Copyright 2013 Unicamp / CCUEC / DDS / CTMQ

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License. 
 */
package br.unicamp.ccuec.ctmq.virusScan.impl;

import java.io.InputStream;
import java.util.logging.Level;
import java.util.logging.Logger;

import br.unicamp.ccuec.ctmq.virusScan.spec.InfraException;
import br.unicamp.ccuec.ctmq.virusScan.spec.VirusException;
import br.unicamp.ccuec.ctmq.virusScan.spec.VirusScan;

/**
 * Classe fake para ambiente de desenvolvimento. Na presenca da propriedade de sistema skipVirusScan = true,
 * sera instanciada sempre esta classe que NAO aciona o anti-virus no servidor.
 * 
 * O metodo scan(String) simula deteccao de virus para desenvolvedor testar mensagem de erro ao usuario final.
 * E demais metodos retornam true.
 * 
 * 
 * @author clayton@ccuec.unicamp.br (Denis Clayton Alves Ramos)
 * 
 */
public class VirusScanFakeImpl extends AbstractVirusScan implements VirusScan {
	private static final Logger _LOGGER = Logger
			.getLogger(VirusScanFakeImpl.class.getName());

	private static final String _INFO_MSG = "\n\n*** EXECUTANDO EM MODO DESENVOLVIMENTO: motor anti-virus do servidor n\u00e3o ser\u00e1 acionado.\n\n";
	private static final String _INFO_MSG_VIRUS = " Status: simula\u00e7\u00e3o virus detectado no ambiente de desenvolvimento! ";

	@Override
	public boolean ping() {
		_LOGGER.log(
				Level.INFO,
				_INFO_MSG + " Retorno false por default!");
		return false;
	}

	@Override
	public boolean scan(String path) throws VirusException, InfraException {
		_LOGGER.log(
				Level.INFO,
				_INFO_MSG + " VirusException lan\u00e7ado!");
		throw new VirusException(_INFO_MSG_VIRUS, new Exception(_INFO_MSG));
	}

	@Override
	public boolean scan(byte[] bytes) throws VirusException, InfraException {
		_LOGGER.log(
				Level.INFO,
				_INFO_MSG + " Retorno true por default!");
		return true;
	}

	@Override
	public boolean scan(InputStream is) throws VirusException, InfraException {
		_LOGGER.log(
				Level.INFO,
				_INFO_MSG + " Retorno true por default!");
		return true;
	}
}